@@ -1,3 +1,27 @@
+#library(nloptr)
+
+GAN_class <- function(a,d,m,eb,es,lk,pin) {
+  value <- list(alpha=a, delta=d, mu=m, epsilon_b=eb, epsilon_s=es, LKval=lk, PIN=pin)
+  attr(value, "class") <- "GAN_class"
+  value
+}
+
+print<-function(obj){
+  UseMethod("print",obj)
+}
+
+# S3 Method for print
+print.GAN_class <- function(obj) {
+  cat("Alpha:", obj$alpha, "\n")
+  cat("Delta:", obj$delta, "\n")
+  cat("Mu:", obj$mu, "\n")
+  cat("Epsilon_b:", obj$epsilon_b, "\n")
+  cat("Epsilon_s:", obj$epsilon_s, "\n")
+  cat("Likelihood Value:", obj$LKval, "\n")
+  cat("PIN:", obj$PIN, "\n")
+}
+
+
 GAN<- function(data, likelihood=c("LK", "EHO")){ 
   
   data = as.data.frame(data)
@@ -10,26 +34,23 @@ GAN<- function(data, likelihood=c("LK", "EHO")){
   data["Imbalance"] = imbalance
   
   # Complete linkage clustering
-  clusters = hclust(dist(data[, "Imbalance"]))
+  clusters = hclust(dist(data[, "Imbalance"]),method="complete")
   clusterCut = cutree(clusters, 3)
   data["Cluster"] = clusterCut
   
   t = table(clusterCut, data$Cluster)
   
-  # Calculate the means of clusters
-  f_clus = t['1',]
-  f_clus = t['1',][which(f_clus > 0)]
-  f_mean = mean(strtoi(names(f_clus)))
+  # Calculate the means of order imbalance for each cluster
+  #First cluster
+  f_mean = mean(data[which(data[,4]==1),][,3])
   
-  s_clus = t['2',]
-  s_clus = t['2',][which(s_clus > 0)]
-  s_mean = mean(strtoi(names(s_clus)))
+  #Second cluster
+  s_mean = mean(data[which(data[,4]==2),][,3])
+
+  #Third cluster
+  t_mean = mean(data[which(data[,4]==3),][,3])
   
-  t_clus = t['3',]
-  t_clus = t['3',][which(t_clus > 0)]
-  t_mean = mean(strtoi(names(t_clus)))
-  
-  # Assign clustering
+  # Assign clustering to good days,bad days, no news days
   means = c(f_mean, s_mean, t_mean)
   good = which(means==max(means))
   bad = which(means==min(means))
@@ -59,17 +80,11 @@ GAN<- function(data, likelihood=c("LK", "EHO")){
   delta_h = w_b/alpha_h
   e_b = (w_b/(w_b+w_n))*(bad_buy_mean) + (w_n/(w_b+w_n))*(no_buy_mean)
   e_s = (w_g/(w_g+w_n))*(good_sell_mean) + (w_n/(w_g+w_n))*(no_sell_mean)
-  mu_b = good_buy_mean - e_b
-  if (mu_b<0){
-    mu_b=0
-  }
-
-  mu_s = bad_sell_mean - e_s
-  if (mu_s<0){
-    mu_s=0
-  }
-  mu = (w_g/(w_b+w_g))*mu_b + (w_b/(w_b+w_g))*mu_s
   
+  mu_b = max(good_buy_mean-e_b,0)
+  mu_s = max(bad_sell_mean-e_s,0)
+  mu = (w_g/(w_g+w_b))*(mu_b) + (w_b/(w_g+w_b))*(mu_s)
+
   par0 = c(alpha_h,delta_h,mu,e_b, e_s)
   if(choice=="LK"){
     nLL<-LK(data)    # Negative log likelihood in Lin and KE form
@@ -78,13 +93,14 @@ GAN<- function(data, likelihood=c("LK", "EHO")){
     nLL<-EHO(data)   # Negative log likelihood in Easleyetal form
   }
   
-  run<-try(model<-optim(par0, nLL, gr = NULL, method = c("Nelder-Mead"), hessian = FALSE)) # Nelder Mean
-  if (class(run)=="try-error"){
-    print("Error in optimization procedure")
-  }
+  #The boundary constraints
+  low=c(0,0,0,0,0)
+  up=c(1,1,Inf,Inf,Inf)
+  
+  model<-neldermead(par0,nLL,lower=low,upper=up)
   
   output<-matrix(nrow=1,ncol=7)
-  
+
   output[1]=model$par[1] # alpha_hat
   output[2]=model$par[2] # delta_hat
   output[3]=model$par[3] # mu_hat
@@ -95,8 +111,8 @@ GAN<- function(data, likelihood=c("LK", "EHO")){
   #Calculates the probability of informed trading 
   output[7]=(output[1]*output[3])/((output[1]*output[3])+output[4]+output[5])
   
-  # Naming the columns and rows
-  colnames(output)<-c("alpha","delta","mu", "epsilon_b","epsilon_s","LikVal","PIN")
-  rownames(output)<-c("Output")
-  return (output)
-}
\ No newline at end of file
+  ret=GAN_class(output[1],output[2],output[3],output[4],output[5],output[6],output[7])
+  
+  return(ret)
+}
+
