@@ -18,34 +18,26 @@ LK <- function(data, fixed=c(FALSE,FALSE,FALSE,FALSE,FALSE)){
   epss <- params[5]; #e_s
   
   #Initialize
-  LK_I <- c(0);
+  LK_I=0;
   
   for (j in 1:trad_days){
     buy_s     <- B[j];
     sell_s    <- S[j];
     
     #Compute values of interest for the log-likelihood function
-    e1<- -mu-sell_s*log(1+(mu/epss))
-    e2<- -mu-buy_s*log(1+(mu/epsb))
-    e3<- -buy_s*log(1+(mu/epsb))-sell_s*log(1+(mu/epss))
+    e1<- (-1)*(mu+buy_s*log(1+(mu/epsb)))
+    e2<- (-1)*(mu+sell_s*log(1+(mu/epss)))
+    e3<- (-1)*(buy_s*log(1+(mu/epsb))+sell_s*log(1+(mu/epss)))
     emax<- max(e1,e2,e3)
     
     #Split the log-likelihood in two parts and compute the relevant terms
-    part1<- -epsb-epss+buy_s*log(mu+epsb)+sell_s*log(mu+epss)+emax
+    part1<- buy_s*log(mu+epsb)+sell_s*log(mu+epss)-(epsb+epss)+emax
     part2<- log(alpha*delta*exp(e1-emax)+alpha*(1-delta)*exp(e2-emax)+(1-alpha)*exp(e3-emax))
     
     LK_I <- LK_I + (part1+part2)
   
   }   
-  
-  #Defining the constraints
-  if ((epsb>=0) && (epss>=0) && (mu>=0) && (alpha>=0) && (delta>=0) &&  (alpha<=1) && (delta<=1)){
-    LK_out <- -LK_I;
-  }else{
-    LK_out <- -Inf;
-  }
-  
-  return(LK_out)
+  return(-LK_I)
   }
 }
   
\ No newline at end of file
