@@ -1,3 +1,24 @@
+YZ_class <- function(a,d,m,eb,es,lk,pin) {
+  value <- list(alpha=a, delta=d, mu=m, epsilon_b=eb, epsilon_s=es, LKval=lk, PIN=pin)
+  attr(value, "class") <- "YZ_class"
+  value
+}
+
+print<-function(obj){
+  UseMethod("print",obj)
+}
+
+# S3 Method for print
+print.YZ_class <- function(obj) {
+  cat("Alpha:", obj$alpha, "\n")
+  cat("Delta:", obj$delta, "\n")
+  cat("Mu:", obj$mu, "\n")
+  cat("Epsilon_b:", obj$epsilon_b, "\n")
+  cat("Epsilon_s:", obj$epsilon_s, "\n")
+  cat("Likelihood Value:", obj$LKval, "\n")
+  cat("PIN:", obj$PIN, "\n")
+}
+
 YZ<-function(data, likelihood=c("LK","EHO")){
   
   # User can choose to run LK or EHO whereas default is "LK"
@@ -14,7 +35,7 @@ YZ<-function(data, likelihood=c("LK","EHO")){
   #Defining variables for the mean buy and sell orders and the max amount of order
   mean_b=mean(Bt)
   mean_s=mean(St)
-  maxim=max(max(Bt),max(St))
+  maxim=max(c(max(Bt),max(St)))
 
   #Setting the input parameter panel
   alpha_in<-c(0.1, 0.3, 0.5, 0.7, 0.9)
@@ -28,27 +49,28 @@ YZ<-function(data, likelihood=c("LK","EHO")){
   #A dummy is created for moving in out matrix. 
   dum=1
   for (i in (1:5)){
-    for( j in (1:5)){
+    for(j in (1:5)){
       for(k in (1:5)){
       
         alpha=alpha_in[i]
       
         delta=delta_in[j]
       
-        eb=gamma_in[k]*mean_b
+        epsilon_b=gamma_in[k]*mean_b
       
-        mu=(mean_b-eb)/(alpha*(1-delta))
+        mu=(mean_b-epsilon_b)/(alpha*(1-delta))
       
-        es=mean_s-(alpha*delta*mu)
+        epsilon_s=mean_s-(alpha*delta*mu)
         
         #YZ indicates that es cannot be negative
         #In addition this part forces to provide initial values for mu that are less maximum value for order.
-        if (es<=0 | mu>maxim){
+        if (epsilon_s<=0 | mu>=maxim){
           dum=dum+1
           next
         }
       
-        par0<-c(alpha,delta,mu,eb,es)
+        par0<-c(alpha,delta,mu,epsilon_b,epsilon_s)
+        
         if(choice=="LK"){
           nLL<-LK(data) #Negative log likelihood in Lin and KE form
         }
@@ -56,12 +78,12 @@ YZ<-function(data, likelihood=c("LK","EHO")){
           nLL<-EHO(data) #Negative log likelihood in Easleyetal form
         }
   
-        ##Optim package###
-          run<-try(model<-optim(par0, nLL, gr = NULL, method = c("Nelder-Mead"), hessian = FALSE))#Nelder Mean
-          if (class(run)=="try-error"){
-            dum=dum+1
-            next
-          }
+        #The boundary constraints
+        low=c(0,0,0,0,0)
+        up=c(1,1,Inf,Inf,Inf)
+        
+        model<-neldermead(par0,nLL,lower=low,upper=up)
+        
           output[dum,1]=model$par[1]# alpha_hat
           output[dum,2]=model$par[2]# delta_hat
           output[dum,3]=model$par[3]# mu_hat
@@ -95,10 +117,9 @@ YZ<-function(data, likelihood=c("LK","EHO")){
   
   #Calculates the probability of informed trading 
   fin_output[7]=(fin_output[1]*fin_output[3])/((fin_output[1]*fin_output[3])+fin_output[3]+fin_output[4])
+  ret=YZ_class(fin_output[1],fin_output[2],fin_output[3],fin_output[4],fin_output[5],fin_output[6],fin_output[7])
+  
+  return(ret)
   
-  # Naming the columns and rows
-  colnames(fin_output)<-c("alpha", "delta", "mu", "epsilon_b", "epsilon_s", "Likval", "PIN")
-  rownames(fin_output)<-c("Output")
-  return(fin_output)
 }
 
